Struct Dispatcher
pub struct Dispatcher<'a, S, Data>(/* private fields */);wayland and Linux only.Expand description
An event source with its callback.
The Dispatcher can be registered in an event loop.
Use the as_source_{ref,mut} functions to interact with the event source.
Use into_source_inner to get the event source back.
Implementations
impl<'a, S, Data> Dispatcher<'a, S, Data>where
S: EventSource + 'a,
impl<'a, S, Data> Dispatcher<'a, S, Data>where
S: EventSource + 'a,
pub fn new<F>(source: S, callback: F) -> Dispatcher<'a, S, Data>where
F: FnMut(<S as EventSource>::Event, &mut <S as EventSource>::Metadata, &mut Data) -> <S as EventSource>::Ret + 'a,
pub fn new<F>(source: S, callback: F) -> Dispatcher<'a, S, Data>where
F: FnMut(<S as EventSource>::Event, &mut <S as EventSource>::Metadata, &mut Data) -> <S as EventSource>::Ret + 'a,
Builds a dispatcher.
The resulting Dispatcher
pub fn as_source_ref(&self) -> Ref<'_, S>
pub fn as_source_ref(&self) -> Ref<'_, S>
Returns an immutable reference to the event source.
Panics
Has the same semantics as RefCell::borrow().
The dispatcher being mutably borrowed while its events are dispatched, this method will panic if invoked from within the associated dispatching closure.
pub fn as_source_mut(&self) -> RefMut<'_, S>
pub fn as_source_mut(&self) -> RefMut<'_, S>
Returns a mutable reference to the event source.
Panics
Has the same semantics as RefCell::borrow_mut().
The dispatcher being mutably borrowed while its events are dispatched, this method will panic if invoked from within the associated dispatching closure.
pub fn into_source_inner(self) -> S
pub fn into_source_inner(self) -> S
Consumes the Dispatcher and returns the inner event source.
Panics
Panics if the Dispatcher is still registered.